@@ -1,6 +1,7 @@
 import random
 
-def _weighted_shuffle(weight_item_pairs,prng=random):
+
+def _weighted_shuffle(weight_item_pairs, prng=random):
     """Shuffle items from weight_item_pairs using weights"""
     pairs = [pair for pair in weight_item_pairs]
     pairs.sort(key=lambda pair: pair[0])
@@ -14,7 +15,7 @@ def _weighted_shuffle(weight_item_pairs,prng=random):
             return choices
 
         # Choose a score
-        score = prng.randint(0, total-1)
+        score = prng.randint(0, total - 1)
 
         # Find the item the score selected
         for j in range(len(pairs)):
@@ -31,6 +32,7 @@ def _weighted_shuffle(weight_item_pairs,prng=random):
     # This line should not be reached
     assert False, "The loop should have already returned."
 
+
 def find_text(service, zone=None):
     """Return a TXT record for the specified service and zone"""
     import dns.resolver
@@ -44,6 +46,7 @@ def find_text(service, zone=None):
 
     return text
 
+
 def find_service(service, zone=None):
     """Return a properly-weighted try list of servers for the specified zone"""
     import dns.resolver
@@ -58,10 +61,11 @@ def find_service(service, zone=None):
 
     # Weighted-random sort each priority tier
     choices = []
-    for priority in sorted(by_priority.keys()):
+    for priority in sorted(by_priority):
         # Prepare the p_list for a weighted shuffle
         p_list = by_priority[priority]
-        pairs = [(record.weight, (record.target.to_text(), record.port)) for record in p_list]
+        pairs = [(record.weight, (record.target.to_text(), record.port))
+                 for record in p_list]
 
         # Add shuffled results to the choices list
         choices += _weighted_shuffle(pairs)
